class IAMPolicies:
    CAN_VIEW_OTHERS_OPERATIONS = 'CAN_VIEW_OTHERS_OPERATIONS'
    CAN_VIEW_OTHERS_WORKFLOWS = 'CAN_VIEW_OTHERS_WORKFLOWS'
    CAN_VIEW_OPERATIONS = 'CAN_VIEW_OPERATIONS'
    CAN_VIEW_WORKFLOWS = 'CAN_VIEW_WORKFLOWS'

    CAN_CREATE_OPERATIONS = 'CAN_CREATE_OPERATIONS'
    CAN_CREATE_WORKFLOWS = 'CAN_CREATE_WORKFLOWS'

    CAN_MODIFY_OTHERS_WORKFLOWS = 'CAN_MODIFY_OTHERS_WORKFLOWS'

    CAN_RUN_WORKFLOWS = 'CAN_RUN_WORKFLOWS'

    IS_ADMIN = 'IS_ADMIN'


class OperationViewSetting:
    KIND_AND_TITLE = 'KIND_AND_TITLE'
    TITLE_AND_DESCRIPTION = 'TITLE_AND_DESCRIPTION'


class UserPostAction:
    MODIFY = 'MODIFY'


class RegisterUserExceptionCode:
    EMPTY_USERNAME = 'EMPTY_USERNAME'
    EMPTY_PASSWORD = 'EMPTY_PASSWORD'
    USERNAME_ALREADY_EXISTS = 'USERNAME_ALREADY_EXISTS'
    EMAIL_ALREADY_EXISTS = 'EMAIL_ALREADY_EXISTS'
    INVALID_EMAIL = 'INVALID_EMAIL'
    INVALID_LENGTH_OF_USERNAME = 'INVALID_LENGTH_OF_USERNAME'
