class NodeNotFound(ImportError):
    pass


class RegisterUserException(Exception):
    def __init__(self, message, error_code):
        super().__init__(message)
        self.message = message
        self.error_code = error_code
